@@ -21,6 +21,9 @@ require 'zip/null_compressor'
 require 'zip/null_input_stream'
 require 'zip/pass_thru_compressor'
 require 'zip/pass_thru_decompressor'
+require 'zip/crypto/encryption'
+require 'zip/crypto/null_encryption'
+require 'zip/crypto/traditional_encryption'
 require 'zip/inflater'
 require 'zip/deflater'
 require 'zip/streamable_stream'
@@ -34,7 +37,7 @@ end
 
 module Zip
   extend self
-  attr_accessor :unicode_names, :on_exists_proc, :continue_on_exists_proc, :sort_entries, :default_compression, :write_zip64_support
+  attr_accessor :unicode_names, :on_exists_proc, :continue_on_exists_proc, :sort_entries, :default_compression, :write_zip64_support, :warn_invalid_date
 
   def reset!
     @_ran_once = false
@@ -44,6 +47,7 @@ module Zip
     @sort_entries = false
     @default_compression = ::Zlib::DEFAULT_COMPRESSION
     @write_zip64_support = false
+    @warn_invalid_date = true
   end
 
   def setup
