@@ -121,11 +121,18 @@ module Zip
         if io.is_a?(::String)
           require 'stringio'
           io = ::StringIO.new(io)
+        elsif io.is_a?(IO)
+          # https://github.com/rubyzip/rubyzip/issues/119
+          io.binmode
         end
         zf = ::Zip::File.new(io, true, true, options)
         zf.read_from_stream(io)
         yield zf
-        zf.write_buffer(io)
+        begin
+          zf.write_buffer(io)
+        rescue IOError => e
+          raise unless e.message == "not opened for writing"
+        end
       end
 
       # Iterates over the contents of the ZipFile. This is more efficient
@@ -403,6 +410,7 @@ module Zip
     def on_success_replace
       tmpfile      = get_tempfile
       tmp_filename = tmpfile.path
+      ObjectSpace.undefine_finalizer(tmpfile)
       tmpfile.close
       if yield tmp_filename
         ::File.rename(tmp_filename, self.name)
@@ -410,6 +418,8 @@ module Zip
           ::File.chmod(@exist_file_perms, self.name)
         end
       end
+    ensure
+      tmpfile.unlink if tmpfile
     end
 
     def get_tempfile
