@@ -1,4 +1,4 @@
-require 'zip/zip'
+require 'zip'
 
 # This is a simple example which uses rubyzip to
 # recursively generate a zip file from the contents of
@@ -7,7 +7,7 @@ require 'zip/zip'
 #
 # Usage:
 #   directoryToZip = "/tmp/input"
-#   outputFile = "/tmp/out.zip"   
+#   outputFile = "/tmp/out.zip"
 #   zf = ZipFileGenerator.new(directoryToZip, outputFile)
 #   zf.write()
 class ZipFileGenerator
@@ -20,7 +20,7 @@ class ZipFileGenerator
 
   # Zip the input directory.
   def write()
-    entries = Dir.entries(@inputDir); entries.delete("."); entries.delete("..") 
+    entries = Dir.entries(@inputDir); entries.delete("."); entries.delete("..")
     io = Zip::File.open(@outputFile, Zip::File::CREATE);
 
     writeEntries(entries, "", io)
@@ -30,20 +30,19 @@ class ZipFileGenerator
   # A helper method to make the recursion work.
   private
   def writeEntries(entries, path, io)
-    
+
     entries.each { |e|
       zipFilePath = path == "" ? e : File.join(path, e)
       diskFilePath = File.join(@inputDir, zipFilePath)
       puts "Deflating " + diskFilePath
       if  File.directory?(diskFilePath)
         io.mkdir(zipFilePath)
-        subdir =Dir.entries(diskFilePath); subdir.delete("."); subdir.delete("..") 
+        subdir =Dir.entries(diskFilePath); subdir.delete("."); subdir.delete("..")
         writeEntries(subdir, zipFilePath, io)
       else
         io.get_output_stream(zipFilePath) { |f| f.puts(File.open(diskFilePath, "rb").read())}
       end
     }
   end
-    
-end
 
+end
